@@ -1,5 +1,4 @@
 //! This part of the library is designed for mathematics and physics - evaluating postfix-notation expressions, unions on customised sets or temperature conversion;Those features are among those implemented for LibRapid.
-mod ztheory; 
 pub mod general;
 pub mod constants;
 pub mod vectors;
@@ -8,3 +7,4 @@ pub mod unit_conversion;
 pub mod primes;
 pub mod sets;
 pub mod equations;
+pub mod complex;
