@@ -1,6 +1,5 @@
 //! Traits and functions for general purpose, everyday mathematics.
 //! Everything you need.
-
 use std::{convert::{TryInto, TryFrom}, ops::*, cmp::*};
 use super::{complex::ComplexNumber, constants::{E, EULERMASCHERONI}};
 use crate::eval_postfix;
@@ -502,4 +501,56 @@ pub fn euler_gamma<T: Into<f64>>(z: T, precision: f64) -> f64 {
                     (1.0 + zdivn);
     }
     pre * res
+}
+
+/// Find the greatest common divisor between two values.
+/// # Arguments
+/// * `a: T` - The first value.
+/// * `b: T` - The second value.
+/// # Returns
+/// A `T`.
+/// # Examples
+/// ```
+/// use lib_rapid::math::general::gcd;
+/// 
+/// assert_eq!(gcd(3, 6), 3);
+/// assert_eq!(gcd(52, 345), 1);
+/// ```
+#[must_use]
+pub fn gcd<T: From<u8> +
+              PartialEq +
+              PartialOrd +
+              Shl<Output = T> +
+              NumTools<T> +
+              Copy +
+              ShrAssign>(a: T, b: T) -> T
+              where
+              i128: From<T> {
+    
+    let mut _a = a;
+    let mut _b = b;
+    if _b == 0.into()
+    { return _a; }
+
+    if _a == 0.into()
+    { return _b; }
+
+    let a_two_factor:   u8 =
+    unsafe { i128::from(_a).trailing_zeros().try_into().unwrap_unchecked() };
+    let b_two_factor:   u8 =
+    unsafe { i128::from(_b).trailing_zeros().try_into().unwrap_unchecked() };
+    let min_two_factor: u8 = std::cmp::min(a_two_factor, b_two_factor);
+    _a >>= a_two_factor.into();
+	_b >>= b_two_factor.into();
+    loop {
+         
+        if _b > _a
+        { std::mem::swap(&mut _b, &mut _a); }
+
+        _a.dec_by(_b);
+
+        if _a == 0.into()
+        { return _b << min_two_factor.into(); }
+        _a >>= unsafe { u8::try_from(i128::from(_a).trailing_zeros()).unwrap_unchecked() }.into();
+    }
 }
\ No newline at end of file
